--- app_meetme.c.orig	2004-05-13 14:47:10.000000000 -0400
+++ app_meetme.c	2004-05-13 18:44:10.000000000 -0400
@@ -33,6 +33,9 @@
 
 #include <pthread.h>
 #include <linux/zaptel.h>
+#include "../asterisk.h"
+#include "../astconf.h"
+
 
 static char *tdesc = "Simple MeetMe conference bridge";
 
@@ -61,7 +64,7 @@
 "      'M' -- enable music on hold when the conference has a single caller\n"
 "      'b' -- run AGI script specified in ${MEETME_AGI_BACKGROUND}\n"
 "	      Default: conf-background.agi\n"
-"             (Note: This does not work with non-Zap channels in the same conference)\n"
+"       (Note: This does not work with non-Zap channels in the same conference)\n"
 "      Not implemented yet:\n"
 "      's' -- send user to admin/user menu if '*' is received\n"
 "      'a' -- set admin mode\n";
@@ -77,21 +80,20 @@
 LOCAL_USER_DECL;
 
 static struct ast_conference {
-	char confno[AST_MAX_EXTENSION];		/* Conference */
+	char confno[AST_MAX_EXTENSION];	/* Conference */
 	int fd;				/* Announcements fd */
 	int zapconf;			/* Zaptel Conf # */
 	int users;			/* Number of active users */
 	time_t start;			/* Start time (s) */
 	int isdynamic;			/* Created on the fly? */
-	char pin[AST_MAX_EXTENSION];			/* If protected by a PIN */
+	char pin[AST_MAX_EXTENSION];	/* If protected by a PIN */
+	unsigned char *enterbip;	/* Enter Beep Data */
+	unsigned char *leavebip;	/* Leave Beep Data */
 	struct ast_conference *next;
 } *confs;
 
 static ast_mutex_t conflock = AST_MUTEX_INITIALIZER;
 
-#include "enter.h"
-#include "leave.h"
-
 #define ENTER	0
 #define LEAVE	1
 
@@ -125,27 +127,62 @@
 	}
 	return 0;
 }
-
+static unsigned char *getfilecontent(char *filename) {
+	FILE *file;
+	static unsigned char *data;
+	unsigned long len;
+	file = fopen(filename, "rb");
+	if (strlen(filename) > 0) {
+		file = fopen(filename, "rb");
+		if (file) {
+			fseek(file, 0, SEEK_END);
+			len=ftell(file);
+			fseek(file, 0, SEEK_SET);
+			data=(char *)malloc(len+1);
+			fread(data, len, 1, file);
+			fclose(file);
+		}
+	}
+	return data;
+}
 static void conf_play(struct ast_conference *conf, int sound)
 {
 	unsigned char *data;
-	int len;
+	unsigned long len;
+	char filename[256];
+
 	ast_mutex_lock(&conflock);
 	switch(sound) {
 	case ENTER:
-		data = enter;
-		len = sizeof(enter);
+		if (conf->enterbip) {
+			data = conf->enterbip;
+		} else {
+			snprintf(filename,sizeof(filename)-1,"%s/%s/enter.raw",(char *)ast_config_AST_VAR_DIR,"sounds");
+			data = getfilecontent(filename);
+			len = strlen(data);
+			conf->enterbip=(unsigned char *)malloc(len+sizeof(unsigned char *));
+			memcpy(conf->enterbip,data,len);	
+		}
 		break;
 	case LEAVE:
-		data = leave;
-		len = sizeof(leave);
+		if (conf->leavebip) {
+			data = conf->leavebip;
+		} else {
+			snprintf(filename,sizeof(filename)-1,"%s/%s/leave.raw",(char *)ast_config_AST_VAR_DIR,"sounds");
+			data = getfilecontent(filename);
+			len = strlen(data);
+			conf->leavebip=(unsigned char *)malloc(len+sizeof(unsigned char *));
+			memcpy(conf->leavebip,data,len);
+		}
+
 		break;
 	default:
 		data = NULL;
 		len = 0;
 	}
-	if (data) 
+	if (data)
 		careful_write(conf->fd, data, len);
+	free(data);
 	ast_mutex_unlock(&conflock);
 }
 
@@ -417,11 +454,11 @@
 			ast_log(LOG_WARNING, "Could not find application (agi)\n");
 			ret = -2;
 		}
-                if (!strcasecmp(chan->type,"Zap")) {
-                        /*  Remove CONFMUTE mode on Zap channel */
+		if (!strcasecmp(chan->type,"Zap")) {
+			/*  Remove CONFMUTE mode on Zap channel */
 			x = 0;
-                        ast_channel_setoption(chan,AST_OPTION_TONE_VERIFY,&x,sizeof(char),0);
-                }
+			ast_channel_setoption(chan,AST_OPTION_TONE_VERIFY,&x,sizeof(char),0);
+		}
 	} else for(;;) {
 		outfd = -1;
 		ms = -1;
